Crate ruprim

Crate ruprim 

Ruda parallel primitives.

Modules

block
Block collectives. Every thread in the block participates in every call.
collective
Operators shared by device, block and logical-warp collectives.
reduce
This provides different implementations of the reduce algorithm which can run on multiple GPU backends using Ruda.
warp
Collectives over logical warps within a native device subgroup.

Macros

ruda_decomposer
Define a lexicographic arithmetic-field decomposition of any width. Fields are listed most significant first; padding is never a sort key.
ruda_record
Define a C-layout record, including nested records, for primitive operators.