pub type C = DynamicScalar<_C>;Expand description
Type to be used as a generic for launch kernel argument.
Aliased Type
pub struct C { /* private fields */ }pub type C = DynamicScalar<_C>;Type to be used as a generic for launch kernel argument.
pub struct C { /* private fields */ }