pub struct RudaReferences<T: RudaRecord, I: RudaAddress<T>> {
pub input: I,
pub marker: PhantomData<T>,
}Fields
input: Imarker: PhantomData<T>Trait Implementations
Sourceimpl<T: Clone + RudaRecord, I: Clone + RudaAddress<T>> Clone for RudaReferences<T, I>
impl<T: Clone + RudaRecord, I: Clone + RudaAddress<T>> Clone for RudaReferences<T, I>
Sourceimpl<T: RudaRecord, I> LaunchArg for RudaReferences<T, I>
impl<T: RudaRecord, I> LaunchArg for RudaReferences<T, I>
Sourcetype RuntimeArg<R: Runtime> = RudaReferencesLaunch<T, I, R>
type RuntimeArg<R: Runtime> = RudaReferencesLaunch<T, I, R>
The runtime argument for the kernel.
Sourcetype CompilationArg = RudaReferencesCompilationArg<T, I>
type CompilationArg = RudaReferencesCompilationArg<T, I>
Compilation argument.
fn register<R: Runtime>( arg: Self::RuntimeArg<R>, launcher: &mut KernelLauncher<R>, ) -> Self::CompilationArg
Sourcefn expand(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an input variable during compilation that fill the
KernelBuilder.Sourcefn expand_output(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand_output( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an output variable during compilation that fill the
KernelBuilder.Sourceimpl<T: RudaRecord, I: RudaAddress<T>> RudaRead<RudaReference<T>> for RudaReferences<T, I>
impl<T: RudaRecord, I: RudaAddress<T>> RudaRead<RudaReference<T>> for RudaReferences<T, I>
fn read(&self, index: usize) -> RudaReference<T>
fn __expand_read( scope: &mut Scope, this: <Self as RudaType>::ExpandType, index: <usize as RudaType>::ExpandType, ) -> <T as RudaType>::ExpandType
Sourceimpl<T: RudaRecord, I: RudaAddress<T>> RudaType for RudaReferences<T, I>
impl<T: RudaRecord, I: RudaAddress<T>> RudaType for RudaReferences<T, I>
type ExpandType = RudaReferencesExpand<T, I>