pub struct RudaZip<I: RudaType, J: RudaType> {
pub first: I,
pub second: J,
}Fields
first: Isecond: JTrait Implementations
Sourceimpl<I, J> LaunchArg for RudaZip<I, J>
impl<I, J> LaunchArg for RudaZip<I, J>
Sourcetype RuntimeArg<R: Runtime> = RudaZipLaunch<I, J, R>
type RuntimeArg<R: Runtime> = RudaZipLaunch<I, J, R>
The runtime argument for the kernel.
Sourcetype CompilationArg = RudaZipCompilationArg<I, J>
type CompilationArg = RudaZipCompilationArg<I, J>
Compilation argument.
fn register<R: Runtime>( arg: Self::RuntimeArg<R>, launcher: &mut KernelLauncher<R>, ) -> Self::CompilationArg
Sourcefn expand(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an input variable during compilation that fill the
KernelBuilder.Sourcefn expand_output(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand_output( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an output variable during compilation that fill the
KernelBuilder.Sourceimpl<A: RudaType, B: RudaType, I: RudaRead<A>, J: RudaRead<B>> RudaRead<RudaPair<A, B>> for RudaZip<I, J>
impl<A: RudaType, B: RudaType, I: RudaRead<A>, J: RudaRead<B>> RudaRead<RudaPair<A, B>> for RudaZip<I, J>
fn read(&self, index: usize) -> RudaPair<A, B>
fn __expand_read( scope: &mut Scope, this: <Self as RudaType>::ExpandType, index: <usize as RudaType>::ExpandType, ) -> <T as RudaType>::ExpandType
Sourceimpl<I: RudaType, J: RudaType> RudaType for RudaZip<I, J>
impl<I: RudaType, J: RudaType> RudaType for RudaZip<I, J>
type ExpandType = RudaZipExpand<I, J>