pub struct RudaDescending;Trait Implementations
Sourceimpl Clone for RudaDescending
impl Clone for RudaDescending
impl Copy for RudaDescending
Sourceimpl Debug for RudaDescending
impl Debug for RudaDescending
Sourceimpl LaunchArg for RudaDescending
impl LaunchArg for RudaDescending
Sourcetype RuntimeArg<R: Runtime> = RudaDescendingLaunch<R>
type RuntimeArg<R: Runtime> = RudaDescendingLaunch<R>
The runtime argument for the kernel.
Sourcetype CompilationArg = RudaDescendingCompilationArg
type CompilationArg = RudaDescendingCompilationArg
Compilation argument.
fn register<R: Runtime>( arg: Self::RuntimeArg<R>, launcher: &mut KernelLauncher<R>, ) -> Self::CompilationArg
Sourcefn expand(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an input variable during compilation that fill the
KernelBuilder.Sourcefn expand_output(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand_output( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an output variable during compilation that fill the
KernelBuilder.Sourceimpl<T: Numeric> RudaCompare<T> for RudaDescending
impl<T: Numeric> RudaCompare<T> for RudaDescending
fn before(&self, left: T, right: T) -> bool
fn __expand_before( scope: &mut Scope, this: <Self as RudaType>::ExpandType, left: <T as RudaType>::ExpandType, right: <T as RudaType>::ExpandType, ) -> <bool as RudaType>::ExpandType
Sourceimpl RudaType for RudaDescending
impl RudaType for RudaDescending