pub struct RudaEqual;Trait Implementations
impl Copy for RudaEqual
Sourceimpl LaunchArg for RudaEqual
impl LaunchArg for RudaEqual
Sourcetype RuntimeArg<R: Runtime> = RudaEqualLaunch<R>
type RuntimeArg<R: Runtime> = RudaEqualLaunch<R>
The runtime argument for the kernel.
Sourcetype CompilationArg = RudaEqualCompilationArg
type CompilationArg = RudaEqualCompilationArg
Compilation argument.
fn register<R: Runtime>( arg: Self::RuntimeArg<R>, launcher: &mut KernelLauncher<R>, ) -> Self::CompilationArg
Sourcefn expand(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an input variable during compilation that fill the
KernelBuilder.Sourcefn expand_output(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand_output( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an output variable during compilation that fill the
KernelBuilder.Sourceimpl<T: Scalar> RudaKeyEqual<T> for RudaEqual
impl<T: Scalar> RudaKeyEqual<T> for RudaEqual
fn equal(&self, left: T, right: T) -> bool
fn __expand_equal( scope: &mut Scope, this: <Self as RudaType>::ExpandType, left: <T as RudaType>::ExpandType, right: <T as RudaType>::ExpandType, ) -> <bool as RudaType>::ExpandType
Sourceimpl RudaType for RudaEqual
impl RudaType for RudaEqual
type ExpandType = RudaEqualExpand