pub struct RudaMaximum;Trait Implementations
Sourceimpl Clone for RudaMaximum
impl Clone for RudaMaximum
Sourcefn clone(&self) -> RudaMaximum
fn clone(&self) -> RudaMaximum
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RudaMaximum
Sourceimpl Debug for RudaMaximum
impl Debug for RudaMaximum
Sourceimpl LaunchArg for RudaMaximum
impl LaunchArg for RudaMaximum
Sourcetype RuntimeArg<R: Runtime> = RudaMaximumLaunch<R>
type RuntimeArg<R: Runtime> = RudaMaximumLaunch<R>
The runtime argument for the kernel.
Sourcetype CompilationArg = RudaMaximumCompilationArg
type CompilationArg = RudaMaximumCompilationArg
Compilation argument.
fn register<R: Runtime>( arg: Self::RuntimeArg<R>, launcher: &mut KernelLauncher<R>, ) -> Self::CompilationArg
Sourcefn expand(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an input variable during compilation that fill the
KernelBuilder.Sourcefn expand_output(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand_output( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an output variable during compilation that fill the
KernelBuilder.Sourceimpl<T: Numeric> RudaBinaryOp<T> for RudaMaximum
impl<T: Numeric> RudaBinaryOp<T> for RudaMaximum
fn combine(&self, left: T, right: T) -> T
fn __expand_combine( scope: &mut Scope, this: <Self as RudaType>::ExpandType, left: <T as RudaType>::ExpandType, right: <T as RudaType>::ExpandType, ) -> <T as RudaType>::ExpandType
Sourceimpl RudaType for RudaMaximum
impl RudaType for RudaMaximum