pub struct RudaMinimum;Trait Implementations
Sourceimpl Clone for RudaMinimum
impl Clone for RudaMinimum
Sourcefn clone(&self) -> RudaMinimum
fn clone(&self) -> RudaMinimum
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RudaMinimum
Sourceimpl Debug for RudaMinimum
impl Debug for RudaMinimum
Sourceimpl LaunchArg for RudaMinimum
impl LaunchArg for RudaMinimum
Sourcetype RuntimeArg<R: Runtime> = RudaMinimumLaunch<R>
type RuntimeArg<R: Runtime> = RudaMinimumLaunch<R>
The runtime argument for the kernel.
Sourcetype CompilationArg = RudaMinimumCompilationArg
type CompilationArg = RudaMinimumCompilationArg
Compilation argument.
fn register<R: Runtime>( arg: Self::RuntimeArg<R>, launcher: &mut KernelLauncher<R>, ) -> Self::CompilationArg
Sourcefn expand(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an input variable during compilation that fill the
KernelBuilder.Sourcefn expand_output(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand_output( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an output variable during compilation that fill the
KernelBuilder.Sourceimpl<T: Numeric> RudaBinaryOp<T> for RudaMinimum
impl<T: Numeric> RudaBinaryOp<T> for RudaMinimum
fn combine(&self, left: T, right: T) -> T
fn __expand_combine( scope: &mut Scope, this: <Self as RudaType>::ExpandType, left: <T as RudaType>::ExpandType, right: <T as RudaType>::ExpandType, ) -> <T as RudaType>::ExpandType
Sourceimpl RudaType for RudaMinimum
impl RudaType for RudaMinimum