pub struct RudaProduct;Trait Implementations
Sourceimpl Clone for RudaProduct
impl Clone for RudaProduct
impl Copy for RudaProduct
Sourceimpl Debug for RudaProduct
impl Debug for RudaProduct
Sourceimpl LaunchArg for RudaProduct
impl LaunchArg for RudaProduct
Sourcetype RuntimeArg<R: Runtime> = RudaProductLaunch<R>
type RuntimeArg<R: Runtime> = RudaProductLaunch<R>
The runtime argument for the kernel.
Sourcetype CompilationArg = RudaProductCompilationArg
type CompilationArg = RudaProductCompilationArg
Compilation argument.
fn register<R: Runtime>( arg: Self::RuntimeArg<R>, launcher: &mut KernelLauncher<R>, ) -> Self::CompilationArg
Sourcefn expand(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an input variable during compilation that fill the
KernelBuilder.Sourcefn expand_output(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand_output( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an output variable during compilation that fill the
KernelBuilder.Sourceimpl<T: Numeric> RudaBinaryOp<T> for RudaProduct
impl<T: Numeric> RudaBinaryOp<T> for RudaProduct
fn combine(&self, left: T, right: T) -> T
fn __expand_combine( scope: &mut Scope, this: <Self as RudaType>::ExpandType, left: <T as RudaType>::ExpandType, right: <T as RudaType>::ExpandType, ) -> <T as RudaType>::ExpandType
Sourceimpl RudaType for RudaProduct
impl RudaType for RudaProduct