pub struct RudaSubtract;Trait Implementations
Sourceimpl Clone for RudaSubtract
impl Clone for RudaSubtract
impl Copy for RudaSubtract
Sourceimpl Debug for RudaSubtract
impl Debug for RudaSubtract
Sourceimpl LaunchArg for RudaSubtract
impl LaunchArg for RudaSubtract
Sourcetype RuntimeArg<R: Runtime> = RudaSubtractLaunch<R>
type RuntimeArg<R: Runtime> = RudaSubtractLaunch<R>
The runtime argument for the kernel.
Sourcetype CompilationArg = RudaSubtractCompilationArg
type CompilationArg = RudaSubtractCompilationArg
Compilation argument.
fn register<R: Runtime>( arg: Self::RuntimeArg<R>, launcher: &mut KernelLauncher<R>, ) -> Self::CompilationArg
Sourcefn expand(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an input variable during compilation that fill the
KernelBuilder.Sourcefn expand_output(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand_output( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an output variable during compilation that fill the
KernelBuilder.Sourceimpl<T: Numeric> RudaBinaryOp<T> for RudaSubtract
impl<T: Numeric> RudaBinaryOp<T> for RudaSubtract
fn combine(&self, left: T, right: T) -> T
fn __expand_combine( scope: &mut Scope, this: <Self as RudaType>::ExpandType, left: <T as RudaType>::ExpandType, right: <T as RudaType>::ExpandType, ) -> <T as RudaType>::ExpandType
Sourceimpl RudaType for RudaSubtract
impl RudaType for RudaSubtract