pub struct RudaSum;Trait Implementations
impl Copy for RudaSum
Sourceimpl LaunchArg for RudaSum
impl LaunchArg for RudaSum
Sourcetype RuntimeArg<R: Runtime> = RudaSumLaunch<R>
type RuntimeArg<R: Runtime> = RudaSumLaunch<R>
The runtime argument for the kernel.
Sourcetype CompilationArg = RudaSumCompilationArg
type CompilationArg = RudaSumCompilationArg
Compilation argument.
fn register<R: Runtime>( arg: Self::RuntimeArg<R>, launcher: &mut KernelLauncher<R>, ) -> Self::CompilationArg
Sourcefn expand(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an input variable during compilation that fill the
KernelBuilder.Sourcefn expand_output(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand_output( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an output variable during compilation that fill the
KernelBuilder.Sourceimpl<T: Numeric> RudaBinaryOp<T> for RudaSum
impl<T: Numeric> RudaBinaryOp<T> for RudaSum
fn combine(&self, left: T, right: T) -> T
fn __expand_combine( scope: &mut Scope, this: <Self as RudaType>::ExpandType, left: <T as RudaType>::ExpandType, right: <T as RudaType>::ExpandType, ) -> <T as RudaType>::ExpandType
Sourceimpl RudaType for RudaSum
impl RudaType for RudaSum
type ExpandType = RudaSumExpand