pub struct RudaIdentity;Trait Implementations
Sourceimpl Clone for RudaIdentity
impl Clone for RudaIdentity
impl Copy for RudaIdentity
Sourceimpl LaunchArg for RudaIdentity
impl LaunchArg for RudaIdentity
Sourcetype RuntimeArg<R: Runtime> = RudaIdentityLaunch<R>
type RuntimeArg<R: Runtime> = RudaIdentityLaunch<R>
The runtime argument for the kernel.
Sourcetype CompilationArg = RudaIdentityCompilationArg
type CompilationArg = RudaIdentityCompilationArg
Compilation argument.
fn register<R: Runtime>( arg: Self::RuntimeArg<R>, launcher: &mut KernelLauncher<R>, ) -> Self::CompilationArg
Sourcefn expand(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an input variable during compilation that fill the
KernelBuilder.Sourcefn expand_output(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand_output( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an output variable during compilation that fill the
KernelBuilder.Sourceimpl RudaType for RudaIdentity
impl RudaType for RudaIdentity
Sourceimpl<T: RudaType> RudaUnaryOp<T, T> for RudaIdentity
impl<T: RudaType> RudaUnaryOp<T, T> for RudaIdentity
fn apply(&self, value: T) -> T
fn __expand_apply( scope: &mut Scope, this: <Self as RudaType>::ExpandType, value: <T as RudaType>::ExpandType, ) -> <U as RudaType>::ExpandType