pub enum BoundChecks {
None,
Mask,
Branch,
}Expand description
How bound checks is handled for inner reductions.
Variants
None
No bound check is necessary.
Mask
Using a mask is enough for bound checks. This will still read the memory in an out-of-bound location, but will replace the value by the null value.
Branch
Branching is necessary for bound checks.
Probably the right setting when performing fuse on read.
Implementations
Sourceimpl BoundChecks
impl BoundChecks