Value

Enum Value 

pub enum Value<X: RudaPrimitive> {
    Multiple(Array<X>),
    Single(ValueWrapper<X>),
    None,
}
Whether the accumulator has zero, one or more vectors

Variants



Multiple(Array<X>)



Single(ValueWrapper<X>)

Wrap the item to be able to modify it as a field



None

Implementations

Source

impl<X: RudaPrimitive> Value<X>

pub fn new_Multiple(_0: Array<X>) -> Self

pub fn __expand_new_Multiple( _: &mut Scope, _0: <Array<X> as RudaType>::ExpandType, ) -> ValueExpand<X>

pub fn new_Single(_0: ValueWrapper<X>) -> Self

pub fn __expand_new_Single( _: &mut Scope, _0: <ValueWrapper<X> as RudaType>::ExpandType, ) -> ValueExpand<X>

pub fn new_None() -> Self

pub fn __expand_new_None(_: &mut Scope) -> ValueExpand<X>

Source

impl<X: RudaPrimitive> Value<X>

pub fn new_single(val: X) -> Value<X>

pub fn item(&self) -> X

pub fn multiple(&self) -> &Array<X> ⓘ

pub fn multiple_mut(&mut self) -> &mut Array<X>

pub fn assign(&mut self, other: &Value<X>)

pub fn __expand_new_single( scope: &mut Scope, val: <X as RudaType>::ExpandType, ) -> <Value<X> as RudaType>::ExpandType

pub fn __expand_item( scope: &mut Scope, this: <Self as RudaType>::ExpandType, ) -> <X as RudaType>::ExpandType

pub fn __expand_multiple( scope: &mut Scope, this: <Self as RudaType>::ExpandType, ) -> <Array<X> as RudaType>::ExpandType ⓘ

pub fn __expand_multiple_mut( scope: &mut Scope, this: <Self as RudaType>::ExpandType, ) -> <Array<X> as RudaType>::ExpandType ⓘ

pub fn __expand_assign( scope: &mut Scope, this: <Self as RudaType>::ExpandType, other: <Value<X> as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType