pub struct ArgMax {}Expand description
Compute the coordinate of the maximum item returning the smallest coordinate in case of equality.
Implementations
Sourceimpl ArgMax
impl ArgMax
Sourcepub fn choose_argmax<T: Numeric, N: Size>(
items0: Vector<T, N>,
coordinates0: Vector<u32, N>,
items1: Vector<T, N>,
coordinates1: Vector<u32, N>,
) -> (Vector<T, N>, Vector<u32, N>)
pub fn choose_argmax<T: Numeric, N: Size>( items0: Vector<T, N>, coordinates0: Vector<u32, N>, items1: Vector<T, N>, coordinates1: Vector<u32, N>, ) -> (Vector<T, N>, Vector<u32, N>)
Compare two pairs of items and coordinates and return a new pair where each element in the vectors is the maximal item with its coordinate. In case of equality, the lowest coordinate is selected.
pub fn __expand_choose_argmax<T: Numeric, N: Size>( scope: &mut Scope, items0: <Vector<T, N> as RudaType>::ExpandType, coordinates0: <Vector<u32, N> as RudaType>::ExpandType, items1: <Vector<T, N> as RudaType>::ExpandType, coordinates1: <Vector<u32, N> as RudaType>::ExpandType, ) -> <(Vector<T, N>, Vector<u32, N>) as RudaType>::ExpandType