pub struct Mean { /* private fields */ }Trait Implementations
Sourceimpl ReduceFamily for Mean
impl ReduceFamily for Mean
type Instruction<P: ReducePrecision> = Mean
type Config = ()
Sourceimpl<P: ReducePrecision> ReduceInstruction<P> for Mean
impl<P: ReducePrecision> ReduceInstruction<P> for Mean
When multiple agents are collaborating to reduce a single slice,
we need a share accumulator to store multiple
AccumulatorItem.
This is most likely a SharedMemory<Vector<T>> or a struct or tuple of vectorized shared memories.type Config = ()
Sourcefn requirements(_this: &Self) -> ReduceRequirements
fn requirements(_this: &Self) -> ReduceRequirements
Requirements of the reduce.
fn accumulator_format(_this: &Self) -> AccumulatorFormat
fn from_config(_config: Self::Config) -> Self
Sourcefn null_input(this: &Self) -> Vector<P::EI, P::SI>
fn null_input(this: &Self) -> Vector<P::EI, P::SI>
A input such that
Self::reduce(accumulator, Self::null_input(), coordinate, use_planes)
is guaranteed to return accumulator unchanged for any choice of coordinate.Sourcefn null_accumulator(this: &Self) -> Accumulator<P>
fn null_accumulator(this: &Self) -> Accumulator<P>
A accumulator such that
Self::fuse_accumulators(accumulator, Self::null_accumulator() always returns
is guaranteed to return accumulator unchanged.Sourcefn reduce(
this: &Self,
accumulator: &mut Accumulator<P>,
item: Item<P>,
reduce_step: ReduceStep,
)
fn reduce( this: &Self, accumulator: &mut Accumulator<P>, item: Item<P>, reduce_step: ReduceStep, )
If
ReduceStep is Plane, reduce all the item and coordinate within the accumulator.
if ReduceStep is Identity, reduce the given item and coordinate into the accumulator.fn plane_reduce_inplace(this: &Self, accumulator: &mut Accumulator<P>)
Sourcefn fuse_accumulators(
this: &Self,
accumulator: &mut Accumulator<P>,
other: &Accumulator<P>,
)
fn fuse_accumulators( this: &Self, accumulator: &mut Accumulator<P>, other: &Accumulator<P>, )
Reduce a whole accumulator (other) in accumulator.
Sourcefn to_output_parallel<Out: Numeric>(
this: &Self,
accumulator: Accumulator<P>,
shape_axis_reduce: VectorSize,
) -> Value<Out>
fn to_output_parallel<Out: Numeric>( this: &Self, accumulator: Accumulator<P>, shape_axis_reduce: VectorSize, ) -> Value<Out>
Reduce all elements of the accumulator into a single output element of type
Out.Sourcefn to_output_perpendicular<Out: Numeric>(
this: &Self,
accumulator: Accumulator<P>,
shape_axis_reduce: VectorSize,
) -> Value<Vector<Out, P::SI>>
fn to_output_perpendicular<Out: Numeric>( this: &Self, accumulator: Accumulator<P>, shape_axis_reduce: VectorSize, ) -> Value<Vector<Out, P::SI>>
Convert each element of the accumulator into the expected output element of type
Out.fn __expand_requirements( scope: &mut Scope, _this: <Self as RudaType>::ExpandType, ) -> <ReduceRequirements as RudaType>::ExpandType
fn __expand_accumulator_format( scope: &mut Scope, _this: <Self as RudaType>::ExpandType, ) -> AccumulatorFormat
fn __expand_from_config( scope: &mut Scope, _config: <Self::Config as RudaType>::ExpandType, ) -> <Self as RudaType>::ExpandType
fn __expand_null_input( scope: &mut Scope, this: <Self as RudaType>::ExpandType, ) -> <Vector<P::EI, P::SI> as RudaType>::ExpandType
fn __expand_null_accumulator( scope: &mut Scope, this: <Self as RudaType>::ExpandType, ) -> <Accumulator<P> as RudaType>::ExpandType
fn __expand_reduce( scope: &mut Scope, this: <Self as RudaType>::ExpandType, accumulator: <Accumulator<P> as RudaType>::ExpandType, item: <Item<P> as RudaType>::ExpandType, reduce_step: ReduceStep, ) -> <() as RudaType>::ExpandType
fn __expand_plane_reduce_inplace( scope: &mut Scope, this: <Self as RudaType>::ExpandType, accumulator: <Accumulator<P> as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType
fn __expand_fuse_accumulators( scope: &mut Scope, this: <Self as RudaType>::ExpandType, accumulator: <Accumulator<P> as RudaType>::ExpandType, other: <Accumulator<P> as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType
fn __expand_to_output_parallel<Out: Numeric>( scope: &mut Scope, this: <Self as RudaType>::ExpandType, accumulator: <Accumulator<P> as RudaType>::ExpandType, shape_axis_reduce: <VectorSize as RudaType>::ExpandType, ) -> <Value<Out> as RudaType>::ExpandType
fn __expand_to_output_perpendicular<Out: Numeric>( scope: &mut Scope, this: <Self as RudaType>::ExpandType, accumulator: <Accumulator<P> as RudaType>::ExpandType, shape_axis_reduce: <VectorSize as RudaType>::ExpandType, ) -> <Value<Vector<Out, P::SI>> as RudaType>::ExpandType
Sourceimpl RudaType for Mean
impl RudaType for Mean
type ExpandType = MeanExpand