pub struct TopK {
pub k: usize,
}Fields
k: usizeTrait Implementations
Sourceimpl ReduceFamily for TopK
impl ReduceFamily for TopK
type Instruction<P: ReducePrecision> = TopK
type Config = usize
Sourceimpl<P: ReducePrecision> ReduceInstruction<P> for TopK
impl<P: ReducePrecision> ReduceInstruction<P> for TopK
When multiple agents are collaborating to reduce a single slice,
we need a share accumulator to store multiple
AccumulatorItem.
This is most likely a SharedMemory<Vector<T>> or a struct or tuple of vectorized shared memories.type Config = usize
Sourcefn requirements(_this: &Self) -> ReduceRequirements
fn requirements(_this: &Self) -> ReduceRequirements
Requirements of the reduce.
fn accumulator_format(this: &Self) -> AccumulatorFormat
fn from_config(config: Self::Config) -> Self
Sourcefn null_input(_this: &Self) -> Vector<P::EI, P::SI>
fn null_input(_this: &Self) -> Vector<P::EI, P::SI>
A input such that
Self::reduce(accumulator, Self::null_input(), coordinate, use_planes)
is guaranteed to return accumulator unchanged for any choice of coordinate.Sourcefn null_accumulator(this: &Self) -> Accumulator<P>
fn null_accumulator(this: &Self) -> Accumulator<P>
A accumulator such that
Self::fuse_accumulators(accumulator, Self::null_accumulator() always returns
is guaranteed to return accumulator unchanged.Sourcefn reduce(
this: &Self,
accumulator: &mut Accumulator<P>,
item: Item<P>,
reduce_step: ReduceStep,
)
fn reduce( this: &Self, accumulator: &mut Accumulator<P>, item: Item<P>, reduce_step: ReduceStep, )
If
ReduceStep is Plane, reduce all the item and coordinate within the accumulator.
if ReduceStep is Identity, reduce the given item and coordinate into the accumulator.fn plane_reduce_inplace(this: &Self, accumulator: &mut Accumulator<P>)
Sourcefn fuse_accumulators(
this: &Self,
accumulator: &mut Accumulator<P>,
other: &Accumulator<P>,
)
fn fuse_accumulators( this: &Self, accumulator: &mut Accumulator<P>, other: &Accumulator<P>, )
Reduce a whole accumulator (other) in accumulator.
Sourcefn to_output_parallel<Out: Numeric>(
this: &Self,
accumulator: Accumulator<P>,
_shape_axis_reduce: usize,
) -> Value<Out>
fn to_output_parallel<Out: Numeric>( this: &Self, accumulator: Accumulator<P>, _shape_axis_reduce: usize, ) -> Value<Out>
Reduce all elements of the accumulator into a single output element of type
Out.Sourcefn to_output_perpendicular<Out: Numeric>(
this: &Self,
accumulator: Accumulator<P>,
_shape_axis_reduce: usize,
) -> Value<Vector<Out, P::SI>>
fn to_output_perpendicular<Out: Numeric>( this: &Self, accumulator: Accumulator<P>, _shape_axis_reduce: usize, ) -> Value<Vector<Out, P::SI>>
Convert each element of the accumulator into the expected output element of type
Out.fn __expand_requirements( scope: &mut Scope, _this: <Self as RudaType>::ExpandType, ) -> <ReduceRequirements as RudaType>::ExpandType
fn __expand_accumulator_format( scope: &mut Scope, this: <Self as RudaType>::ExpandType, ) -> AccumulatorFormat
fn __expand_from_config( scope: &mut Scope, config: Self::Config, ) -> <Self as RudaType>::ExpandType
fn __expand_null_input( scope: &mut Scope, _this: <Self as RudaType>::ExpandType, ) -> <Vector<P::EI, P::SI> as RudaType>::ExpandType
fn __expand_null_accumulator( scope: &mut Scope, this: <Self as RudaType>::ExpandType, ) -> <Accumulator<P> as RudaType>::ExpandType
fn __expand_reduce( scope: &mut Scope, this: <Self as RudaType>::ExpandType, accumulator: <Accumulator<P> as RudaType>::ExpandType, item: <Item<P> as RudaType>::ExpandType, reduce_step: ReduceStep, ) -> <() as RudaType>::ExpandType
fn __expand_plane_reduce_inplace( scope: &mut Scope, this: <Self as RudaType>::ExpandType, accumulator: <Accumulator<P> as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType
fn __expand_fuse_accumulators( scope: &mut Scope, this: <Self as RudaType>::ExpandType, accumulator: <Accumulator<P> as RudaType>::ExpandType, other: <Accumulator<P> as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType
fn __expand_to_output_parallel<Out: Numeric>( scope: &mut Scope, this: <Self as RudaType>::ExpandType, accumulator: <Accumulator<P> as RudaType>::ExpandType, _shape_axis_reduce: <usize as RudaType>::ExpandType, ) -> <Value<Out> as RudaType>::ExpandType
fn __expand_to_output_perpendicular<Out: Numeric>( scope: &mut Scope, this: <Self as RudaType>::ExpandType, accumulator: <Accumulator<P> as RudaType>::ExpandType, _shape_axis_reduce: <usize as RudaType>::ExpandType, ) -> <Value<Vector<Out, P::SI>> as RudaType>::ExpandType
Sourceimpl RudaType for TopK
impl RudaType for TopK
type ExpandType = TopKExpand
fn allocate(length: usize, _coordinate: bool, inst: &TopK) -> Self
fn read(accumulator: &Self, index: usize) -> Accumulator<P>
fn write(accumulator: &mut Self, index: usize, item: Accumulator<P>)
fn __expand_allocate( scope: &mut Scope, length: usize, _coordinate: bool, inst: <TopK as RudaType>::ExpandType, ) -> <Self as RudaType>::ExpandType
fn __expand_read( scope: &mut Scope, accumulator: <Self as RudaType>::ExpandType, index: <usize as RudaType>::ExpandType, ) -> <Accumulator<P> as RudaType>::ExpandType
fn __expand_write( scope: &mut Scope, accumulator: <Self as RudaType>::ExpandType, index: <usize as RudaType>::ExpandType, item: <Accumulator<P> as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType