pub enum RoutineStrategy {
Unit(BlueprintStrategy<UnitRoutine>),
Plane(BlueprintStrategy<PlaneRoutine>),
Ruda(BlueprintStrategy<RudaRoutine>),
}Variants
Unit(BlueprintStrategy<UnitRoutine>)
A unit is responsible to reduce a full vector.
Plane(BlueprintStrategy<PlaneRoutine>)
A plane is responsible to reduce a full vector.
Ruda(BlueprintStrategy<RudaRoutine>)
A ruda is responsible to reduce a full vector.