pub type Out = DynamicScalar<_Out>;Expand description
Type to be used as a generic for launch kernel argument.
Aliased Type
pub struct Out { /* private fields */ }pub type Out = DynamicScalar<_Out>;Type to be used as a generic for launch kernel argument.
pub struct Out { /* private fields */ }