pub struct VectorizationStrategy {
pub parallel_output_vectorization: bool,
}Fields
parallel_output_vectorization: boolWhen the vectorization is parallel, enable vectorization of the output so that each
unit can perform N reductions, where N is the output vector_size.