Block collectives. Every thread in the block participates in every call.
Modules
- adjacent
- exchange
- exclusive_
scan - histogram
- inclusive_
scan - io
- radix
- raking
- rank
- record
- reduce
- run_
length - scan_
with_ prefix - shuffle
- sort
- topk
Traits
Functions
- exclusive_
scan - Ordered exclusive scan. Returns the unseeded aggregate to every thread.
- inclusive_
scan - Ordered inclusive scan of a blocked register tile.
Scratch contains
threads * items_per_threadelements.valid_itemsis uniform and positive; invalid output elements are unspecified. - reduce
- Ordered tree reduction; the aggregate is broadcast to all block threads.
valid_itemsmust be positive. Input is in blocked register order. - scan_
with_ prefix - Inclusive/exclusive scan with a stateful block prefix callback. The first
native subgroup invokes the callback, and thread zero’s result is used.
Scratch requires
threads * items_per_thread + 1entries. Valid input is positive and callback state updates occur on the participating threads.