pub struct RudaNativeRecords {
pub address: u64,
pub stride: u64,
}Expand description
A device-native strided record range. Addresses and strides are in bytes. The caller retains the allocation and guarantees alignment and bounds for every access, including any references retained by an operation.
Fields
address: u64stride: u64Trait Implementations
Sourceimpl Clone for RudaNativeRecords
impl Clone for RudaNativeRecords
Sourcefn clone(&self) -> RudaNativeRecords
fn clone(&self) -> RudaNativeRecords
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RudaNativeRecords
Sourceimpl LaunchArg for RudaNativeRecords
impl LaunchArg for RudaNativeRecords
Sourcetype RuntimeArg<R: Runtime> = RudaNativeRecordsLaunch<R>
type RuntimeArg<R: Runtime> = RudaNativeRecordsLaunch<R>
The runtime argument for the kernel.
Sourcetype CompilationArg = RudaNativeRecordsCompilationArg
type CompilationArg = RudaNativeRecordsCompilationArg
Compilation argument.
fn register<R: Runtime>( arg: Self::RuntimeArg<R>, launcher: &mut KernelLauncher<R>, ) -> Self::CompilationArg
Sourcefn expand(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an input variable during compilation that fill the
KernelBuilder.Sourcefn expand_output(
arg: &Self::CompilationArg,
builder: &mut KernelBuilder,
) -> <Self as RudaType>::ExpandType
fn expand_output( arg: &Self::CompilationArg, builder: &mut KernelBuilder, ) -> <Self as RudaType>::ExpandType
Register an output variable during compilation that fill the
KernelBuilder.Sourceimpl<T: RudaRecord> RudaAddress<T> for RudaNativeRecords
impl<T: RudaRecord> RudaAddress<T> for RudaNativeRecords
fn reference(&self, index: usize) -> RudaReference<T>
fn __expand_reference( scope: &mut Scope, this: <Self as RudaType>::ExpandType, index: <usize as RudaType>::ExpandType, ) -> <RudaReference<T> as RudaType>::ExpandType
Sourceimpl<T: RudaRecord> RudaRead<T> for RudaNativeRecords
impl<T: RudaRecord> RudaRead<T> for RudaNativeRecords
fn read(&self, index: usize) -> T
fn __expand_read( scope: &mut Scope, this: <Self as RudaType>::ExpandType, index: <usize as RudaType>::ExpandType, ) -> <T as RudaType>::ExpandType
Sourceimpl RudaType for RudaNativeRecords
impl RudaType for RudaNativeRecords
Sourceimpl<T: RudaRecord> RudaWrite<T> for RudaNativeRecords
impl<T: RudaRecord> RudaWrite<T> for RudaNativeRecords
fn write(&mut self, index: usize, value: T)
fn __expand_write( scope: &mut Scope, this: <Self as RudaType>::ExpandType, index: <usize as RudaType>::ExpandType, value: <T as RudaType>::ExpandType, ) -> <() as RudaType>::ExpandType